pub type SqlType = (Int8, Nullable<Text>, Nullable<Text>, Text, Timestamptz, Timestamptz);Expand description
The SQL type of all of the columns on this table
pub type SqlType = (Int8, Nullable<Text>, Nullable<Text>, Text, Timestamptz, Timestamptz);The SQL type of all of the columns on this table